## Description

A pattern for making long, unwieldy select boxes much more user-friendly.

## Documentation

Be sure to include the chosen.css file, by placing this line in the head of your HTML document.

  <link rel="stylesheet" type="text/css" href="/src/bower_components/chosen/chosen/chosen.css">

### Examples

####This will display a searchable ddropdown list of the following countries with a placeholder text of 'Select an Option'.
	
	<select class="pat-chosen" style="width:350px">
		<option value="" disabled selected hidden>Select an Option</option>
        <option value="United States">United States</option>
        <option value="United Kingdom">United Kingdom</option>
        <option value="Afghanistan">Afghanistan</option>
        <option value="Aland Islands">Aland Islands</option>
        <option value="Albania">Albania</option>
        <option value="Algeria">Algeria</option>       
	</select>



